from . import importexport

def abaqus_hexahedron_writer(data_container_array, output_path = None, file_prefix = None, feature_ids_array_path = None, hourglass_stiffness = None, job_name = None, observer = None) -> int:
  """
  AbaqusHexahedronWriter

  :param data_container_array | DataContainerArray
  :param output_path | QString OutputPath
  :param file_prefix | QString FilePrefix
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param hourglass_stiffness | int HourglassStiffness
  :param job_name | QString JobName
  :param observer | Observer
  """

  filter = importexport.AbaqusHexahedronWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if file_prefix is not None:
    filter.FilePrefix = file_prefix
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if hourglass_stiffness is not None:
    filter.HourglassStiffness = hourglass_stiffness
  if job_name is not None:
    filter.JobName = job_name
  filter.execute()
  return filter.ErrorCode

def abaqus_surface_mesh_writer(data_container_array, output_file = None, surface_mesh_face_labels_array_path = None, observer = None) -> int:
  """
  AbaqusSurfaceMeshWriter

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param surface_mesh_face_labels_array_path | DataArrayPath SurfaceMeshFaceLabelsArrayPath
  :param observer | Observer
  """

  filter = importexport.AbaqusSurfaceMeshWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  filter.execute()
  return filter.ErrorCode

def avizo_rectilinear_coordinate_writer(data_container_array, output_file = None, write_binary_file = None, units = None, feature_ids_array_path = None, observer = None) -> int:
  """
  AvizoRectilinearCoordinateWriter

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param write_binary_file | bool WriteBinaryFile
  :param units | QString Units
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param observer | Observer
  """

  filter = importexport.AvizoRectilinearCoordinateWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if units is not None:
    filter.Units = units
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def avizo_uniform_coordinate_writer(data_container_array, output_file = None, write_binary_file = None, units = None, feature_ids_array_path = None, observer = None) -> int:
  """
  AvizoUniformCoordinateWriter

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param write_binary_file | bool WriteBinaryFile
  :param units | QString Units
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param observer | Observer
  """

  filter = importexport.AvizoUniformCoordinateWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if units is not None:
    filter.Units = units
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def dx_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, file_was_read = None, feature_ids_array_name = None, observer = None) -> int:
  """
  DxReader

  :param data_container_array | DataContainerArray
  :param volume_data_container_name | DataArrayPath VolumeDataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param input_file | QString InputFile
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param file_was_read | bool FileWasRead
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param observer | Observer
  """

  filter = importexport.DxReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def dx_writer(data_container_array, add_surface_layer = None, feature_ids_array_path = None, observer = None) -> int:
  """
  DxWriter

  :param data_container_array | DataContainerArray
  :param add_surface_layer | bool AddSurfaceLayer
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param observer | Observer
  """

  filter = importexport.DxWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if add_surface_layer is not None:
    filter.AddSurfaceLayer = add_surface_layer
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def feature_info_reader(data_container_array, cell_attribute_matrix_name = None, cell_feature_attribute_matrix_name = None, input_file = None, create_cell_level_arrays = None, renumber_features = None, feature_ids_array_path = None, cell_phases_array_name = None, cell_euler_angles_array_name = None, feature_phases_array_name = None, feature_euler_angles_array_name = None, observer = None) -> int:
  """
  FeatureInfoReader

  :param data_container_array | DataContainerArray
  :param cell_attribute_matrix_name | DataArrayPath CellAttributeMatrixName
  :param cell_feature_attribute_matrix_name | QString CellFeatureAttributeMatrixName
  :param input_file | QString InputFile
  :param create_cell_level_arrays | bool CreateCellLevelArrays
  :param renumber_features | bool RenumberFeatures
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param cell_phases_array_name | QString CellPhasesArrayName
  :param cell_euler_angles_array_name | QString CellEulerAnglesArrayName
  :param feature_phases_array_name | QString FeaturePhasesArrayName
  :param feature_euler_angles_array_name | QString FeatureEulerAnglesArrayName
  :param observer | Observer
  """

  filter = importexport.FeatureInfoReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if create_cell_level_arrays is not None:
    filter.CreateCellLevelArrays = create_cell_level_arrays
  if renumber_features is not None:
    filter.RenumberFeatures = renumber_features
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if cell_euler_angles_array_name is not None:
    filter.CellEulerAnglesArrayName = cell_euler_angles_array_name
  if feature_phases_array_name is not None:
    filter.FeaturePhasesArrayName = feature_phases_array_name
  if feature_euler_angles_array_name is not None:
    filter.FeatureEulerAnglesArrayName = feature_euler_angles_array_name
  filter.execute()
  return filter.ErrorCode

def gbcd_triangle_dumper(data_container_array, output_file = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_face_areas_array_path = None, feature_euler_angles_array_path = None, observer = None) -> int:
  """
  GBCDTriangleDumper

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param surface_mesh_face_labels_array_path | DataArrayPath SurfaceMeshFaceLabelsArrayPath
  :param surface_mesh_face_normals_array_path | DataArrayPath SurfaceMeshFaceNormalsArrayPath
  :param surface_mesh_face_areas_array_path | DataArrayPath SurfaceMeshFaceAreasArrayPath
  :param feature_euler_angles_array_path | DataArrayPath FeatureEulerAnglesArrayPath
  :param observer | Observer
  """

  filter = importexport.GBCDTriangleDumper()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_face_areas_array_path is not None:
    filter.SurfaceMeshFaceAreasArrayPath = surface_mesh_face_areas_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def los_alamos_fft_writer(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """
  LosAlamosFFTWriter

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param cell_euler_angles_array_path | DataArrayPath CellEulerAnglesArrayPath
  :param observer | Observer
  """

  filter = importexport.LosAlamosFFTWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def ph_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, file_was_read = None, feature_ids_array_name = None, observer = None) -> int:
  """
  PhReader

  :param data_container_array | DataContainerArray
  :param volume_data_container_name | DataArrayPath VolumeDataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param input_file | QString InputFile
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param file_was_read | bool FileWasRead
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param observer | Observer
  """

  filter = importexport.PhReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def ph_writer(data_container_array, feature_ids_array_path = None, observer = None) -> int:
  """
  PhWriter

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param observer | Observer
  """

  filter = importexport.PhWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def read_stl_file(data_container_array, surface_mesh_data_container_name = None, face_attribute_matrix_name = None, stl_file_path = None, face_normals_array_name = None, observer = None) -> int:
  """
  ReadStlFile

  :param data_container_array | DataContainerArray
  :param surface_mesh_data_container_name | DataArrayPath SurfaceMeshDataContainerName
  :param face_attribute_matrix_name | QString FaceAttributeMatrixName
  :param stl_file_path | QString StlFilePath
  :param face_normals_array_name | QString FaceNormalsArrayName
  :param observer | Observer
  """

  filter = importexport.ReadStlFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_data_container_name is not None:
    filter.SurfaceMeshDataContainerName = surface_mesh_data_container_name
  if face_attribute_matrix_name is not None:
    filter.FaceAttributeMatrixName = face_attribute_matrix_name
  if stl_file_path is not None:
    filter.StlFilePath = stl_file_path
  if face_normals_array_name is not None:
    filter.FaceNormalsArrayName = face_normals_array_name
  filter.execute()
  return filter.ErrorCode

def sp_parks_dump_reader(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, input_file = None, origin = None, spacing = None, one_based_arrays = None, feature_ids_array_name = None, observer = None) -> int:
  """
  SPParksDumpReader

  :param data_container_array | DataContainerArray
  :param volume_data_container_name | DataArrayPath VolumeDataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param input_file | QString InputFile
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param one_based_arrays | bool OneBasedArrays
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param observer | Observer
  """

  filter = importexport.SPParksDumpReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if one_based_arrays is not None:
    filter.OneBasedArrays = one_based_arrays
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def sp_parks_sites_writer(data_container_array, feature_ids_array_path = None, observer = None) -> int:
  """
  SPParksSitesWriter

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param observer | Observer
  """

  filter = importexport.SPParksSitesWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def visualize_gbcdgmt(data_container_array, output_file = None, phase_of_interest = None, misorientation_rotation = None, gbcd_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """
  VisualizeGBCDGMT

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param phase_of_interest | int PhaseOfInterest
  :param misorientation_rotation | AxisAngleInput MisorientationRotation
  :param gbcd_array_path | DataArrayPath GBCDArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param observer | Observer
  """

  filter = importexport.VisualizeGBCDGMT()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if misorientation_rotation is not None:
    filter.MisorientationRotation = misorientation_rotation
  if gbcd_array_path is not None:
    filter.GBCDArrayPath = gbcd_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def visualize_gbcd_pole_figure(data_container_array, output_file = None, phase_of_interest = None, misorientation_rotation = None, gbcd_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """
  VisualizeGBCDPoleFigure

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param phase_of_interest | int PhaseOfInterest
  :param misorientation_rotation | AxisAngleInput MisorientationRotation
  :param gbcd_array_path | DataArrayPath GBCDArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param observer | Observer
  """

  filter = importexport.VisualizeGBCDPoleFigure()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if misorientation_rotation is not None:
    filter.MisorientationRotation = misorientation_rotation
  if gbcd_array_path is not None:
    filter.GBCDArrayPath = gbcd_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def vtk_rectilinear_grid_writer(data_container_array, output_file = None, write_binary_file = None, selected_data_array_paths = None, observer = None) -> int:
  """
  VtkRectilinearGridWriter

  :param data_container_array | DataContainerArray
  :param output_file | QString OutputFile
  :param write_binary_file | bool WriteBinaryFile
  :param selected_data_array_paths | std::vector<DataArrayPath> SelectedDataArrayPaths
  :param observer | Observer
  """

  filter = importexport.VtkRectilinearGridWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if write_binary_file is not None:
    filter.WriteBinaryFile = write_binary_file
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  filter.execute()
  return filter.ErrorCode

def vtk_structured_points_reader(data_container_array, read_cell_data = None, volume_data_container_name = None, cell_attribute_matrix_name = None, read_point_data = None, vertex_data_container_name = None, vertex_attribute_matrix_name = None, input_file = None, observer = None) -> int:
  """
  VtkStructuredPointsReader

  :param data_container_array | DataContainerArray
  :param read_cell_data | bool ReadCellData
  :param volume_data_container_name | DataArrayPath VolumeDataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param read_point_data | bool ReadPointData
  :param vertex_data_container_name | DataArrayPath VertexDataContainerName
  :param vertex_attribute_matrix_name | QString VertexAttributeMatrixName
  :param input_file | QString InputFile
  :param observer | Observer
  """

  filter = importexport.VtkStructuredPointsReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if read_cell_data is not None:
    filter.ReadCellData = read_cell_data
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if read_point_data is not None:
    filter.ReadPointData = read_point_data
  if vertex_data_container_name is not None:
    filter.VertexDataContainerName = vertex_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  filter.execute()
  return filter.ErrorCode

def write_stl_file(data_container_array, output_stl_directory = None, output_stl_prefix = None, group_by_phase = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_phases_array_path = None, observer = None) -> int:
  """
  WriteStlFile

  :param data_container_array | DataContainerArray
  :param output_stl_directory | QString OutputStlDirectory
  :param output_stl_prefix | QString OutputStlPrefix
  :param group_by_phase | bool GroupByPhase
  :param surface_mesh_face_labels_array_path | DataArrayPath SurfaceMeshFaceLabelsArrayPath
  :param surface_mesh_face_phases_array_path | DataArrayPath SurfaceMeshFacePhasesArrayPath
  :param observer | Observer
  """

  filter = importexport.WriteStlFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_stl_directory is not None:
    filter.OutputStlDirectory = output_stl_directory
  if output_stl_prefix is not None:
    filter.OutputStlPrefix = output_stl_prefix
  if group_by_phase is not None:
    filter.GroupByPhase = group_by_phase
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_phases_array_path is not None:
    filter.SurfaceMeshFacePhasesArrayPath = surface_mesh_face_phases_array_path
  filter.execute()
  return filter.ErrorCode

